#!/usr/bin/env python
# -*- coding: utf-8 -*-

# UVSnap Module.

"""
UVSnap Module.
~~~~


:author: Greg Albrecht <oss@undef.net>
:copyright: Copyright 2017 Greg Albrecht
:license: Apache License, Version 2.0
:source: <https://github.com/ampledata/uvsnap>

"""

from .constants import LOG_FORMAT, LOG_LEVEL  # NOQA
from .classes import NVR  # NOQA

__author__ = 'Greg Albrecht <oss@undef.net>'
__copyright__ = 'Copyright 2017 Greg Albrecht'
__license__ = 'Apache License, Version 2.0'
